aboutsummaryrefslogtreecommitdiff
path: root/src/common/dwarf/dwarf2reader.cc
diff options
context:
space:
mode:
Diffstat (limited to 'src/common/dwarf/dwarf2reader.cc')
-rw-r--r--src/common/dwarf/dwarf2reader.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/common/dwarf/dwarf2reader.cc b/src/common/dwarf/dwarf2reader.cc
index 87741225..f2dc4afe 100644
--- a/src/common/dwarf/dwarf2reader.cc
+++ b/src/common/dwarf/dwarf2reader.cc
@@ -1265,12 +1265,12 @@ class CallFrameInfo::Rule {
public:
virtual ~Rule() { }
// Tell HANDLER that, at ADDRESS in the program, REGISTER can be
// recovered using this rule. If REGISTER is kCFARegister, then this rule
// describes how to compute the canonical frame address. Return what the
// HANDLER member function returned.
virtual bool Handle(Handler *handler,
- uint64 address, int register) const = 0;
+ uint64 address, int reg) const = 0;
// Equality on rules. We use these to decide which rules we need
// to report after a DW_CFA_restore_state instruction.
@@ -1265,12 +1265,12 @@ class CallFrameInfo::Rule {
public:
virtual ~Rule() { }
- // Tell HANDLER that, at ADDRESS in the program, REGISTER can be
- // recovered using this rule. If REGISTER is kCFARegister, then this rule
- // describes how to compute the canonical frame address. Return what the
- // HANDLER member function returned.
+ // Tell HANDLER that, at ADDRESS in the program, REG can be recovered using
+ // this rule. If REG is kCFARegister, then this rule describes how to compute
+ // the canonical frame address. Return what the HANDLER member function
+ // returned.
virtual bool Handle(Handler *handler,